==> newswire-6.x-1.2-beta1.tar.gz: newswire/page.tpl.php <==
<?php // $Id: page.tpl.php,v 1.4 2008/08/12 16:44:42 jmburnz Exp $ 
/**
 * @file page.tpl.php
 *
 * Theme implementation to display a single Drupal page.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 */
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language->language; ?>" xml:lang="<?php print $language->language; ?>">
<head>
  <title><?php print $head_title; ?></title>
  <?php print $head; ?>
  <?php print $styles; ?>
  <!--[if IE]>
    <link rel="stylesheet" href="<?php print $base_path . $directory; ?>/ie.css" type="text/css">
  <![endif]-->
  <?php print $scripts; ?>
</head>
<body class="<?php print newswire_column_count_class($left, $content, $right, $right_2) . $body_class; ?>">
  <div id="container">
    <!-- SKIP NAV -->
	<div id="accessiblity" class="width-48-950 last nofloat">
	  <a href="#content"><?php print t('Skip to content'); ?></a>
	</div>
    <?php if ($leaderboard): ?>
	  <!-- LEADERBOARD -->
      <div id="leaderboard" class="width-48-950 last nofloat">
        <?php print $leaderboard; ?>
      </div> <!-- /leaderboard -->
    <?php endif; ?>
    <?php if ($logo || $site_name || $site_slogan || $search_box): ?>
	  <!-- HEADER -->
      <div id="header" class="width-48-950 last nofloat">
        <?php if ($logo || $site_name || $site_slogan): ?>
		  <div class="branding width-30-590">
            <?php 
              if ($logo) {
                print $logo;
              }
              else {
                print $site_name;
              }
            ?>        
		    <?php if ($site_slogan): ?>
              <em><?php print $site_slogan; ?></em>
            <?php endif; ?>
          </div> <!-- /branding -->
        <?php endif; ?>
		<?php if ($search_box): ?>
		  <div id="search-box-top" class="width-18-350 last">
		    <?php print $search_box; ?>
          </div> <!-- /search -->
		<?php endif; ?>
      </div> <!-- /header -->
    <?php endif; ?>
	<!-- TOP NAVIGATION -->
	<div id="primary-navigation" class="width-48-950 last nofloat">
      <?php if ($primary_links): ?>
	    <!-- PRIMARY -->
        <div class="primary-menu width-46-910">
          <?php print theme('links', $primary_links); ?>
        </div> <!-- /primary -->
      <?php endif; ?>
	    <!-- FEED ICON / RSS -->
        <div class="feed-icons width-2-30 last clearfix">
          <a href="<?php print $base_path; ?>rss.xml" class="feed-icon"><img src="<?php print $base_path . $directory; ?>/images/feed.png" alt="Syndicate content" title="RSS Feed" width="16" height="16" /></a> 
        </div> <!-- /rss icon -->
    </div>
    <?php if ($secondary_links): ?> 
	  <!-- SECONDARY -->
      <div id="secondary-menu" class="width-48-950 last nofloat">
	    <?php print theme('links', $secondary_links); ?>
	  </div>
    <?php endif; ?>  
	<?php if ($header): ?>
      <div id="header" class="width-48-950 last nofloat">
        <?php print $header; ?>
      </div> <!-- /header -->
    <?php endif; ?>
	<?php if ($content_top_full_width || $content_top_left || $content_top_content): ?>
	  <!-- CONTENT TOP -->
	  <div id="content-top" class="width-48-950 last nofloat">
	    <?php if ($content_top_full_width): ?>
		  <div id="content-top-full-width" class="width-48-950 last nofloat">
	        <?php print $content_top_full_width; ?>
		  </div> <!-- /content-top-full-width -->
		<?php endif; ?>
        <?php if ($content_top_left): ?>
          <div class="content-top-col-1 width-24-470">
            <?php print $content_top_left; ?>
          </div> <!-- /content-top-col-1 -->
        <?php endif; ?>
	    <?php if ($content_top_content): ?>
          <div class="content-top-col-2 width-24-470 last">
            <?php print $content_top_content; ?>
          </div> <!-- /content-top-col-2 -->
        <?php endif; ?>
      </div> <!-- /content-top -->
	<?php endif; ?>
	<!-- MAIN CONTENT -->
    <div id="col_wrapper" class="width-960">
	  <?php if ($left): ?>
	    <!-- LEFT -->
        <div id="left" class="width-10-190">
          <?php print $left; ?>
        </div> <!-- /left -->
      <?php endif; ?>
	  <!-- CONTENT -->
      <div id="content" class="<?php print newswire_col_width($left, $content, $right, $right_2); ?>">
        <?php print $breadcrumb; ?>
        <?php if ($title): ?>
		  <?php print $title; ?>
        <?php endif; ?>
        <?php if ($messages): ?>
		  <div id="messages"><?php print $messages; ?></div>
		<?php endif; ?>
        <?php if ($tabs): ?>
          <div class="tabs"><?php print $tabs; ?></div>
        <?php endif; ?>
        <?php print $help; ?>
        <?php if ($mission): ?>
          <div class="mission padded-box"><?php print $mission; ?></div>
        <?php endif; ?>
		<?php print $content; ?> 
      </div> <!-- /content -->
	  <?php if ($right_2): ?>
	    <!-- RIGHT 2 -->
        <div id="right_2" class="width-10-190">
          <?php print $right_2; ?>
        </div> <!-- /right 2 -->
      <?php endif; ?>
	  <?php if ($right): ?>
	    <!-- RIGHT -->
        <div id="right" class="width-10-190 last">
          <?php print $right; ?>
        </div> <!-- /right -->
      <?php endif; ?>
	</div> <!-- /col_wrapper-->
	<?php if ($content_bottom_full_width || $content_bottom_left || $content_bottom_content): ?>
	  <!-- CONTENT BOTTOM -->
	  <div id="content-bottom" class="width-48-950 last nofloat">
        <?php if ($content_bottom_left): ?>
          <div class="content-bottom-col-1 width-24-470">
            <?php print $content_bottom_left; ?>
          </div> <!-- /content-bottom-col-1 -->
        <?php endif; ?>
	    <?php if ($content_bottom_content): ?>
          <div class="content-bottom-col-2 width-24-470 last">
            <?php print $content_bottom_content; ?>
          </div> <!-- /content-bottom-col-2 -->
        <?php endif; ?>
		<?php if ($content_bottom_full_width): ?>
		  <div id="content-bottom-full-width" class="width-48-950 last nofloat">
	        <?php print $content_bottom_full_width; ?>
		  </div> <!-- /content-bottom-full-width -->
		<?php endif; ?>
      </div> <!-- /content-bottom -->
	<?php endif; ?>
	<!-- FOOTER -->
	<div id="footer" class="wwidth-48-950 last nofloat">
	  <?php print $footer; ?>
	</div>  <!-- /footer -->
	<?php if ($footer_message): ?>
	  <!-- FOOTER MESSAGE-->
	  <div id="footer-message" class="width-48-950 last nofloat small">
	    <?php print $footer_message ?>
	  </div>  <!-- /footer message -->
	<?php endif; ?>
	<div id="adaptivethemes">
      <a href="http://adaptivethemes.com">AdaptiveThemes</a>
    </div>
    <?php print $closure ?>
  </div> <!-- /container -->
</body>
</html>

==> newswire-6.x-2.0-beta1.tar.gz: newswire/page.tpl.php <==
<?php // $Id: page.tpl.php,v 1.5 2008/08/21 21:58:40 jmburnz Exp $ 
/**
 * @file page.tpl.php
 *
 * Theme implementation to display a single Drupal page.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 */
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language->language; ?>" xml:lang="<?php print $language->language; ?>">
<head>
  <title><?php print $head_title; ?></title>
  <?php print $head; ?>
  <?php print $styles; ?>
  <!--[if IE]>
    <link rel="stylesheet" href="<?php print $base_path . $directory; ?>/ie.css" type="text/css">
  <![endif]-->
  <?php if (!empty($suckerfish)): ?>
  <!--[if lte IE 6]>
    <script type="text/javascript" src="<?php print $base_path . $directory; ?>/js/suckerfish.js"></script>
  <![endif]-->
   <?php endif; ?>
  <?php print $scripts; ?>
</head>
<body class="<?php print newswire_column_count_class($left, $content, $right, $right_2) . $body_class; ?>">
  <div id="container">
    <!-- SKIP NAV -->
	<div id="accessiblity" class="width-48-950 last nofloat">
	  <a href="#content"><?php print t('Skip to content'); ?></a>
	</div>
    <?php if ($leaderboard): ?>
	  <!-- LEADERBOARD -->
      <div id="leaderboard" class="width-48-950 last nofloat">
        <?php print $leaderboard; ?>
      </div> <!-- /leaderboard -->
    <?php endif; ?>
    <?php if ($logo || $site_name || $site_slogan || $search_box): ?>
	  <!-- HEADER -->
      <div id="header" class="width-48-950 last nofloat">
        <?php if ($logo || $site_name || $site_slogan): ?>
		  <div class="branding width-30-590">
            <?php 
              if ($logo) {
                print $logo;
              }
              else {
                print $site_name;
              }
            ?>        
		    <?php if ($site_slogan): ?>
              <em><?php print $site_slogan; ?></em>
            <?php endif; ?>
          </div> <!-- /branding -->
        <?php endif; ?>
		<?php if ($search_box): ?>
		  <div id="search-box-top" class="width-18-350 last">
		    <?php print $search_box; ?>
          </div> <!-- /search -->
		<?php endif; ?>
      </div> <!-- /header -->
    <?php endif; ?>
	<!-- TOP NAVIGATION -->
	<div id="main-navigation" class="width-48-950 last nofloat">
      <?php if ($primary_links || $suckerfish): ?>
	    <!-- PRIMARY -->
        <div id="<?php print $primary_links ? 'primary-menu' : 'suckerfish' ; ?>" class="width-46-910">
          <?php if ($primary_links) {
		          print theme('links', $primary_links); 
				}
				elseif (!empty($suckerfish)) {
				  print $suckerfish;
				}
		  ?>
        </div> <!-- /primary -->
      <?php endif; ?>
	    <!-- FEED ICON / RSS -->
        <div class="feed-icons width-2-30 last clearfix">
          <a href="<?php print $base_path; ?>rss.xml" class="feed-icon">
		  <img src="<?php print $base_path . $directory; ?>/images/feed.png" alt="Syndicate content" title="RSS Feed" width="16" height="16" />
		  </a> 
        </div> <!-- /rss icon -->
    </div>
    <?php if ($secondary_links): ?> 
	  <!-- SECONDARY -->
      <div id="secondary-menu" class="width-48-950 last nofloat">
	    <?php print theme('links', $secondary_links); ?>
	  </div>
    <?php endif; ?>  
	<?php if ($header): ?>
      <div id="header" class="width-48-950 last nofloat">
        <?php print $header; ?>
      </div> <!-- /header -->
    <?php endif; ?>
	<?php if ($content_top_full_width || $content_top_left || $content_top_content): ?>
	  <!-- CONTENT TOP -->
	  <div id="content-top" class="width-48-950 last nofloat">
	    <?php if ($content_top_full_width): ?>
		  <div id="content-top-full-width" class="width-48-950 last nofloat">
	        <?php print $content_top_full_width; ?>
		  </div> <!-- /content-top-full-width -->
		<?php endif; ?>
        <?php if ($content_top_left): ?>
          <div class="content-top-col-1 width-24-470">
            <?php print $content_top_left; ?>
          </div> <!-- /content-top-col-1 -->
        <?php endif; ?>
	    <?php if ($content_top_content): ?>
          <div class="content-top-col-2 width-24-470 last">
            <?php print $content_top_content; ?>
          </div> <!-- /content-top-col-2 -->
        <?php endif; ?>
      </div> <!-- /content-top -->
	<?php endif; ?>
	<!-- MAIN CONTENT -->
    <div id="col_wrapper" class="width-960">
	  <?php if ($left): ?>
	    <!-- LEFT -->
        <div id="left" class="width-10-190">
          <?php print $left; ?>
        </div> <!-- /left -->
      <?php endif; ?>
	  <!-- CONTENT -->
      <div id="content" class="<?php print newswire_col_width($left, $content, $right, $right_2); ?>">
        <?php print $breadcrumb; ?>
        <?php if ($title): ?>
		  <?php print $title; ?>
        <?php endif; ?>
        <?php if ($messages): ?>
		  <div id="messages"><?php print $messages; ?></div>
		<?php endif; ?>
        <?php if ($tabs): ?>
          <div class="tabs"><?php print $tabs; ?></div>
        <?php endif; ?>
        <?php print $help; ?>
        <?php if ($mission): ?>
          <div class="mission"><?php print $mission; ?></div>
        <?php endif; ?>
		<?php print $content; ?> 
      </div> <!-- /content -->
	  <?php if ($right_2): ?>
	    <!-- RIGHT 2 -->
        <div id="right_2" class="width-10-190">
          <?php print $right_2; ?>
        </div> <!-- /right 2 -->
      <?php endif; ?>
	  <?php if ($right): ?>
	    <!-- RIGHT -->
        <div id="right" class="width-10-190 last">
          <?php print $right; ?>
        </div> <!-- /right -->
      <?php endif; ?>
	</div> <!-- /col_wrapper-->
	<?php if ($content_bottom_full_width || $content_bottom_left || $content_bottom_content): ?>
	  <!-- CONTENT BOTTOM -->
	  <div id="content-bottom" class="width-48-950 last nofloat">
        <?php if ($content_bottom_left): ?>
          <div class="content-bottom-col-1 width-24-470">
            <?php print $content_bottom_left; ?>
          </div> <!-- /content-bottom-col-1 -->
        <?php endif; ?>
	    <?php if ($content_bottom_content): ?>
          <div class="content-bottom-col-2 width-24-470 last">
            <?php print $content_bottom_content; ?>
          </div> <!-- /content-bottom-col-2 -->
        <?php endif; ?>
		<?php if ($content_bottom_full_width): ?>
		  <div id="content-bottom-full-width" class="width-48-950 last nofloat">
	        <?php print $content_bottom_full_width; ?>
		  </div> <!-- /content-bottom-full-width -->
		<?php endif; ?>
      </div> <!-- /content-bottom -->
	<?php endif; ?>
	<!-- FOOTER -->
	<div id="footer" class="wwidth-48-950 last nofloat">
	  <?php print $footer; ?>
	</div>  <!-- /footer -->
	<?php if ($footer_message): ?>
	  <!-- FOOTER MESSAGE-->
	  <div id="footer-message" class="width-48-950 last nofloat small">
	    <?php print $footer_message ?>
	  </div>  <!-- /footer message -->
	<?php endif; ?>
	<div id="adaptivethemes">
      <a href="http://adaptivethemes.com">AdaptiveThemes</a>
    </div>
    <?php print $closure ?>
  </div> <!-- /container -->
</body>
</html>
